=========
dbexample
=========

.. image:: https://github.com/st3107/dbexample/workflows/test/badge.svg
        :target: https://github.com/st3107/dbexample/actions

.. image:: https://img.shields.io/pypi/v/dbexample.svg
        :target: https://pypi.python.org/pypi/dbexample


An example nsls-ii database that can be accessed by the databroker.

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://st3107.github.io/dbexample.
